@@ -2,13 +2,12 @@ from dateutil import parser
 from typing import List, Dict, Tuple
 from oc_ocdm.graph import GraphEntity
 from oc_ocdm.prov.prov_entity import ProvEntity
-from oc_ocdm.support import get_count, find_paths
+from oc_ocdm.support import get_count
 from rdflib import Graph, Literal, URIRef
-from SPARQLWrapper import SPARQLWrapper, JSON, GET, RDFXML
+from SPARQLWrapper import SPARQLWrapper, JSON, GET, XML
 from time_agnostic_library.agnostic_entity import AgnosticEntity
 
 
-
 class ResourceFinder:
 
     def __init__(self, ts_url, base_iri:str):
@@ -35,6 +34,7 @@ class ResourceFinder:
         :returns List[Tuple[str, str, list]]: -- it returns a list of three elements tuples. The first element is the MetaID of a resource associated with the input ID. The second element is a title of that resourse, if present. The third element is a list of MetaID-ID tuples related to identifiers associated with that resource. 
         '''
         schema = GraphEntity.DATACITE + schema
+        value = value.replace('\\', '\\\\')
         query = f'''
             SELECT DISTINCT ?res (GROUP_CONCAT(DISTINCT ?title; separator=' ;and; ') AS ?title_)
                 (GROUP_CONCAT(DISTINCT ?otherId; separator=' ;and; ') AS ?otherId_)
@@ -129,6 +129,7 @@ class ResourceFinder:
         :returns str: -- it returns the MetaID associated with the input ID.
         '''
         schema = GraphEntity.DATACITE + schema
+        value = value.replace('\\', '\\\\')
         query = f'''
             SELECT DISTINCT ?res 
             WHERE {{
@@ -262,6 +263,7 @@ class ResourceFinder:
         :returns List[Tuple[str, str, list]]: -- it returns a list of three elements tuples. The first element is the MetaID of a responsible agent associated with the input ID. The second element is the name of that responsible agent, if present. The third element is a list of MetaID-ID tuples related to identifiers associated with that responsible agent. 
         '''
         schema = GraphEntity.DATACITE + schema
+        value = value.replace('\\', '\\\\')
         query = f'''
             SELECT DISTINCT ?res
                 (GROUP_CONCAT(DISTINCT ?name; separator=' ;and; ') AS ?name_)
@@ -714,7 +716,7 @@ class ResourceFinder:
                     <{res}> ?p ?o.
                 }}
             """
-            self.ts.setReturnFormat(RDFXML)
+            self.ts.setReturnFormat(XML)
             graph_subj = self.__query(query_subj)
             untyped_graph_subj = Graph()
             for triple in graph_subj.triples((None, None, None)):
