@@ -15,9 +15,9 @@
 # SOFTWARE.
 
 
-from oc_meta.lib.file_manager import pathoo, get_data, write_csv, sort_files
-from oc_meta.lib.master_of_regex import comma_and_spaces, ids_inside_square_brackets, name_and_ids, semicolon_in_people_field
-from oc_meta.scripts.creator import Creator
+from oc_meta.lib.file_manager import pathoo, get_csv_data, write_csv, sort_files
+from oc_meta.lib.master_of_regex import comma_and_spaces, name_and_ids, semicolon_in_people_field
+from oc_meta.core.creator import Creator
 from typing import Dict, List
 from tqdm import tqdm
 import os
@@ -49,22 +49,17 @@ def prepare_relevant_items(csv_dir:str, output_dir:str, items_per_file:int, verb
     pathoo(output_dir)
     ids_found = set()
     venues_found = dict()
-    vi_with_editor_found = dict()
     duplicated_ids = dict()
     venues_by_id = dict()
     duplicated_venues = dict()
-    publishers_found = set()
-    publishers_by_id = dict()
-    duplicated_publishers = dict()
     resp_agents_found = set()
     resp_agents_by_id = dict()
     duplicated_resp_agents = dict()
     # Look for all venues, responsible agents, and publishers
     for file in files:
-        data = get_data(file)
-        _get_duplicated_ids(data=data, ids_found=ids_found, vi_with_editor_found=vi_with_editor_found, items_by_id=duplicated_ids)
+        data = get_csv_data(file)
+        _get_duplicated_ids(data=data, ids_found=ids_found, items_by_id=duplicated_ids)
         _get_relevant_venues(data=data, ids_found=venues_found, items_by_id=venues_by_id, duplicated_items=duplicated_venues)
-        _get_publishers(data=data, ids_found=publishers_found, items_by_id=publishers_by_id, duplicated_items=duplicated_publishers)
         _get_resp_agents(data=data, ids_found=resp_agents_found, items_by_id=resp_agents_by_id, duplicated_items=duplicated_resp_agents)
         pbar.update() if verbose else None
     pbar.close() if verbose else None
@@ -72,48 +67,24 @@ def prepare_relevant_items(csv_dir:str, output_dir:str, items_per_file:int, verb
         print('[INFO:prepare_multiprocess] Enriching the duplicated bibliographic resources found')
         pbar = tqdm(total=len(files))
     for file in files:
-        data = get_data(file)
+        data = get_csv_data(file)
         _enrich_duplicated_ids_found(data, duplicated_ids)
         pbar.update() if verbose else None
     pbar.close() if verbose else None
     ids_merged = _do_collective_merge(duplicated_ids, duplicated_ids)
     venues_merged = _do_collective_merge(venues_by_id, duplicated_venues)
-    publishers_merged = _do_collective_merge(publishers_by_id, duplicated_publishers)
     resp_agents_merged = _do_collective_merge(resp_agents_by_id, duplicated_resp_agents)
     fieldnames = ['id', 'title', 'author', 'pub_date', 'venue', 'volume', 'issue', 'page', 'type', 'publisher', 'editor']
     __save_relevant_venues(venues_merged, items_per_file, output_dir, fieldnames)
     __save_ids(ids_merged, items_per_file, output_dir, fieldnames)
-    __save_responsible_agents(resp_agents_merged, items_per_file, output_dir, fieldnames, ('people', 'author'))
-    __save_responsible_agents(publishers_merged, items_per_file, output_dir, fieldnames, ('publishers', 'publisher'))
+    for field in ['author', 'editor', 'publisher']:
+        __save_responsible_agents(resp_agents_merged, items_per_file, output_dir, fieldnames, field)
 
-def _get_duplicated_ids(data:List[dict], ids_found:set, vi_with_editor_found:dict, items_by_id:Dict[str, dict]) -> None:
+def _get_duplicated_ids(data:List[dict], ids_found:set, items_by_id:Dict[str, dict]) -> None:
     cur_file_ids = set()
-    cur_file_vi_with_editor = dict()
     for row in data:
         ids_list = row['id'].split()
-        venue_ids = re.search(ids_inside_square_brackets, row['venue'])
-        venue_ids = venue_ids.group(1) if venue_ids else None
-        venue_ids_list = [identifier for identifier in venue_ids.split() if identifier not in FORBIDDEN_IDS] if venue_ids else []
-        editor_refers_to_vi = bool(row['type'] == 'journal article' and row['author'] and row['editor'] and venue_ids_list and (row['issue'] or row['volume']))
-        for id in venue_ids_list:
-            cur_file_vi_with_editor.setdefault(id, {'volumes': dict(), 'issues': set()})
-            vi_with_editor_found.setdefault(id, {'volumes': dict(), 'issues': set()})
-        duplicated_editor = False
-        if editor_refers_to_vi:
-            if row['volume']:
-                for venue_id in venue_ids_list:
-                    if row['volume'] in vi_with_editor_found[venue_id]['volumes'] and row['volume'] not in cur_file_vi_with_editor[venue_id]['volumes']:
-                        if row['issue']:
-                            if row['issue'] in vi_with_editor_found[venue_id]['volumes'][row['volume']]:
-                                duplicated_editor = True
-                        else:
-                            duplicated_editor = True
-            elif row['issue'] and not row['volume']:
-                for venue_id in venue_ids_list: 
-                    if row['issue'] in vi_with_editor_found[venue_id]['issues'] and row['issue'] not in cur_file_vi_with_editor[venue_id]['issues']:
-                        duplicated_editor = True
-        if any(id in ids_found and (id not in cur_file_ids or id in items_by_id) for id in ids_list) or \
-                duplicated_editor:
+        if any(id in ids_found and (id not in cur_file_ids or id in items_by_id) for id in ids_list):
             for id in ids_list:
                 items_by_id.setdefault(id, {'others': set()})
                 items_by_id[id]['others'].update({other for other in ids_list if other != id})
@@ -124,16 +95,6 @@ def _get_duplicated_ids(data:List[dict], ids_found:set, vi_with_editor_found:dic
                     items_by_id[id][field] = row[field]
         cur_file_ids.update(set(ids_list))   
         ids_found.update(set(ids_list))
-        for id in venue_ids_list:
-            if row['volume']:
-                cur_file_vi_with_editor[id]['volumes'].setdefault(row['volume'], set())
-                vi_with_editor_found[id]['volumes'].setdefault(row['volume'], set())
-                if row['issue']:
-                    cur_file_vi_with_editor[id]['volumes'][row['volume']].add(row['issue'])
-                    vi_with_editor_found[id]['volumes'][row['volume']].add(row['issue'])
-            elif row['issue'] and not row['volume']:
-                cur_file_vi_with_editor[id]['issues'].add(row['issue'])
-                vi_with_editor_found[id]['issues'].add(row['issue'])
 
 def _enrich_duplicated_ids_found(data:List[dict], items_by_id:Dict[str, dict]) -> None:
     for row in data:
@@ -175,7 +136,6 @@ def _get_relevant_venues(data:List[dict], ids_found:dict, items_by_id:Dict[str,
             for id in ids_list:
                 items_by_id.setdefault(id, {'others': set(), 'name': name, 'type': br_type, 'volume': dict(), 'issue': set()})
                 items_by_id[id]['others'].update({other for other in ids_list if other != id})
-            for id in ids_list:
                 ids_found.setdefault(id, {'volumes': dict(), 'issues': set()})
                 cur_file_ids.setdefault(id, {'volumes': dict(), 'issues': set()})
             volume = row['volume']
@@ -203,29 +163,12 @@ def _get_relevant_venues(data:List[dict], ids_found:dict, items_by_id:Dict[str,
                     ids_found[id]['issues'].add(row['issue'])
                     cur_file_ids[id]['issues'].add(row['issue'])
                 
-def _get_publishers(data:List[dict], ids_found:set, items_by_id:Dict[str, dict], duplicated_items:Dict[str, dict]) -> None:
-    cur_file_ids = set()
-    for row in data:
-        pub_name_and_ids = re.search(name_and_ids, row['publisher'])
-        if pub_name_and_ids:
-            pub_name = pub_name_and_ids.group(1)
-            pub_ids = pub_name_and_ids.group(2).split()
-            if any(id in ids_found and (id not in cur_file_ids or id in duplicated_items) for id in pub_ids):
-                for pub_id in pub_ids:
-                    duplicated_items.setdefault(pub_id, {'others': set(), 'name': pub_name, 'type': 'publisher'})
-                    duplicated_items[pub_id]['others'].update({other for other in pub_ids if other != pub_id})
-            for pub_id in pub_ids:
-                items_by_id.setdefault(pub_id, {'others': set(), 'name': pub_name, 'type': 'publisher'})
-                items_by_id[pub_id]['others'].update({other for other in pub_ids if other != pub_id})
-            cur_file_ids.update(set(pub_ids))   
-            ids_found.update(set(pub_ids))
-
 def _get_resp_agents(data:List[dict], ids_found:set, items_by_id:Dict[str, Dict[str, set]], duplicated_items:Dict[str, dict]) -> None:
     cur_file_ids = set()
     for row in data:
-        for field in {'author', 'editor'}:
+        for field in {'author', 'editor', 'publisher'}:
             if row[field]:
-                resp_agents = re.split(semicolon_in_people_field, row[field])
+                resp_agents = re.split(semicolon_in_people_field, row[field]) if field in {'author', 'editor'} else [row[field]]
                 for resp_agent in resp_agents:
                     full_name_and_ids = re.search(name_and_ids, resp_agent)
                     name = full_name_and_ids.group(1) if full_name_and_ids else resp_agent
@@ -235,39 +178,41 @@ def _get_resp_agents(data:List[dict], ids_found:set, items_by_id:Dict[str, Dict[
                         richest_name = _find_all_names(duplicated_items, ids_list, name)
                         if any(id in ids_found and (id not in cur_file_ids or id in duplicated_items) for id in ids_list):
                             for id in ids_list:
-                                duplicated_items.setdefault(id, {'others': set(), 'type': 'author'})
+                                duplicated_items.setdefault(id, {'others': set(), 'type': field})
                                 duplicated_items[id]['name'] = richest_name
                                 duplicated_items[id]['others'].update({other for other in ids_list if other != id})
                         for id in ids_list:
-                            items_by_id.setdefault(id, {'others': set(), 'type': 'author'})
+                            items_by_id.setdefault(id, {'others': set(), 'type': field})
                             items_by_id[id]['name'] = richest_name
                             items_by_id[id]['others'].update({other for other in ids_list if other != id})
                         cur_file_ids.update(set(ids_list))   
                         ids_found.update(set(ids_list))
 
 def _find_all_names(items_by_id:Dict[str, Dict[str, set]], ids_list:list, cur_name:str) -> str:
-    all_names = {cur_name}
+    if ',' in cur_name:
+        split_name = re.split(comma_and_spaces, cur_name)
+        given_name = split_name[1].strip()
+        if given_name and not (given_name.endswith('.') or len(given_name) == 1):
+            return cur_name
     for id in ids_list:
         if id in items_by_id:
-            all_names.add(items_by_id[id]['name'])
-    all_names_parsed = set()
-    for name in all_names:
-        if ',' in name:
-            split_name = re.split(comma_and_spaces, name)
-            first_name = split_name[1].strip()
-            surname = split_name[0].strip()
-            all_names_parsed.add((surname, first_name))
-        else:
-            all_names_parsed.add((name,))
-    richest_first_name = ''
-    richest_surname = ''
-    for name in all_names_parsed:
-        if name[0] > richest_surname:
-            richest_surname = name[0]
-        if len(name) == 2:
-            if name[1] > richest_first_name:
-                richest_first_name = name[1]
-    return f'{richest_surname}, {richest_first_name}'.strip()
+            other_name = items_by_id[id]['name']
+            if ',' in other_name:
+                split_other_name = re.split(comma_and_spaces, other_name)
+                family_other_name = split_other_name[0].strip()
+                given_other_name = split_other_name[1].strip()
+                if given_other_name and not (given_other_name.endswith('.') or len(given_other_name) == 1):
+                    return family_other_name + ', ' + given_other_name
+    for id in ids_list:
+        if id in items_by_id:
+            other_name = items_by_id[id]['name']
+            if ',' in other_name:
+                split_other_name = re.split(comma_and_spaces, other_name)
+                family_other_name = split_other_name[0].strip()
+                given_other_name = split_other_name[1].strip()
+                if given_other_name:
+                    return family_other_name + ', ' + given_other_name
+    return cur_name
 
 def _do_collective_merge(items_by_id:dict, duplicated_items:Dict[str, dict]) -> dict:
     merged_by_key:Dict[str, Dict[str, set]] = dict()
@@ -360,18 +305,17 @@ def __save_relevant_venues(items_by_id:dict, items_per_file:int, output_dir:str,
     output_path = os.path.join(output_dir, f"{counter}.csv")
     write_csv(output_path, rows, fieldnames)
 
-def __save_responsible_agents(items_by_id:dict, items_per_file:int, output_dir:str, fieldnames:list, datatype:tuple):
-    folder = datatype[0]
-    field = datatype[1]
-    output_dir = os.path.join(output_dir, folder)
+def __save_responsible_agents(items_by_id:dict, items_per_file:int, output_dir:str, fieldnames:list, field:str):
     rows = list()
     chunks = int(items_per_file)
     saved_chunks = 0
-    output_length = len(items_by_id)
-    for item_id, data in items_by_id.items():
+    items_to_be_processed = {k:v for k,v in items_by_id.items() if v['type'] == field}
+    output_length = len(items_to_be_processed)
+    for item_id, data in items_to_be_processed.items():
         name, ids = __get_name_and_ids(item_id, data)
+        output_path = os.path.join(output_dir, field + 's')
         rows.append({field: f'{name} [{ids}]'})
-        rows, saved_chunks = __store_data(rows, output_length, chunks, saved_chunks, output_dir, fieldnames)
+        rows, saved_chunks = __store_data(rows, output_length, chunks, saved_chunks, output_path, fieldnames)
 
 def __save_ids(items_by_id:dict, items_per_file:int, output_dir:str, fieldnames:list):
     output_dir = os.path.join(output_dir, 'ids')
@@ -434,7 +378,7 @@ def __index_all_venues(files:list, verbose:bool) -> dict:
         pbar = tqdm(total=len(files))
     venues_occurrences = dict()
     for file in files:
-        data = get_data(file)
+        data = get_csv_data(file)
         for row in data:
             venues = list()
             if row['type'] in VENUES:
@@ -462,7 +406,7 @@ def __split_csvs_by_venues(files:list, venues_occurrences:dict, output_dir:str,
     no_venues_outdata = list()
     counter = 0
     for file in files:
-        data = get_data(file)
+        data = get_csv_data(file)
         for row in data:
             venues = list()
             if row['type'] in VENUES:
@@ -499,7 +443,7 @@ def __split_csvs_by_venues(files:list, venues_occurrences:dict, output_dir:str,
         chunk_no_venues[no_venues_filepath] = no_venues_outdata
     for chunk in [chunk_venues, chunk_no_venues]:
         for filepath, dump in chunk.items():
-            all_data = get_data(filepath) if os.path.exists(filepath) else list()
+            all_data = get_csv_data(filepath) if os.path.exists(filepath) else list()
             all_data.extend(dump)
             write_csv(filepath, all_data)
         del chunk
@@ -514,7 +458,7 @@ def __split_in_chunks(output_dir:str, chunk_size:int, verbose:bool):
     counter = 0
     for file in files:
         filepath = os.path.join(output_dir, file)
-        data = get_data(filepath)
+        data = get_csv_data(filepath)
         len_data = len(data)
         if len_data > chunk_size:
             while len_data > chunk_size:
@@ -543,20 +487,9 @@ def __dump_if_chunk_size(chunk:dict, existing_files:set, pid:psutil.Process) ->
     memory_used = pid.memory_info().rss / (1024.0 ** 3)
     if memory_used > 10:
         for filepath, dump in chunk.items():
-            all_data = get_data(filepath) if os.path.exists(filepath) else list()
+            all_data = get_csv_data(filepath) if os.path.exists(filepath) else list()
             all_data.extend(dump)
             write_csv(filepath, all_data)
             existing_files.add(filepath)
         return dict()
-    return chunk
-
-def __find_all_ids_by_key(items_by_id:dict, key:str):
-    visited_items = set()
-    items_to_visit = {item for item in items_by_id[key]['others']}
-    while items_to_visit:
-        for item in set(items_to_visit):
-            if item not in visited_items:
-                visited_items.add(item)
-                items_to_visit.update({item for item in items_by_id[item]['others'] if item not in visited_items})
-            items_to_visit.remove(item)
-    return visited_items
+    return chunk
\ No newline at end of file
