@@ -20,20 +20,17 @@
 
 from argparse import ArgumentParser
 from datetime import datetime
-from filelock import FileLock
 from itertools import cycle
-from oc_meta.lib.csvmanager import CSVManager
-from oc_meta.lib.file_manager import get_data, normalize_path, pathoo, suppress_stdout, init_cache, sort_files
+from oc_meta.lib.file_manager import get_csv_data, normalize_path, pathoo, suppress_stdout, init_cache, sort_files, zipit
 from oc_meta.plugins.multiprocess.resp_agents_creator import RespAgentsCreator
 from oc_meta.plugins.multiprocess.resp_agents_curator import RespAgentsCurator
-from oc_meta.scripts.creator import Creator
-from oc_meta.scripts.curator import Curator
+from oc_meta.core.creator import Creator
+from oc_meta.core.curator import Curator
 from oc_ocdm import Storer
 from oc_ocdm.prov import ProvSet
-from pathlib import Path
+from oc_ocdm.support.reporter import Reporter
 from pebble import ProcessPool, ProcessFuture
-from shutil import make_archive
-from sys import platform
+from sys import executable, platform
 from time_agnostic_library.support import generate_config_file
 from typing import List, Set, Tuple
 import csv
@@ -53,7 +50,8 @@ class MetaProcess:
         self.resp_agent = settings['resp_agent']
         self.info_dir = os.path.join(self.base_output_dir, 'info_dir')
         self.output_csv_dir = os.path.join(self.base_output_dir, 'csv')
-        self.output_rdf_dir = os.path.join(self.base_output_dir, f'rdf{os.sep}')
+        self.distinct_output_dirs = True if settings['base_output_dir'] != settings['output_rdf_dir'] else False
+        self.output_rdf_dir = normalize_path(settings['output_rdf_dir']) + os.sep + 'rdf' + os.sep
         self.indexes_dir = os.path.join(self.base_output_dir, 'indexes')
         self.cache_path = os.path.join(self.base_output_dir, 'cache.txt')
         self.errors_path = os.path.join(self.base_output_dir, 'errors.txt')
@@ -64,24 +62,25 @@ class MetaProcess:
         self.items_per_file = settings['items_per_file']
         self.default_dir = settings['default_dir']
         self.rdf_output_in_chunks = settings['rdf_output_in_chunks']
+        self.zip_output_rdf = settings['zip_output_rdf']
         self.source = settings['source']
-        self.valid_dois_cache = CSVManager() if bool(settings['use_doi_api_service']) == True else None
+        self.valid_dois_cache = dict() if bool(settings['use_doi_api_service']) == True else None
         self.workers_number = int(settings['workers_number'])
         supplier_prefix:str = settings['supplier_prefix']
         self.supplier_prefix = supplier_prefix[:-1] if supplier_prefix.endswith('0') else supplier_prefix
-        self.verbose = settings['verbose']
         # Time-Agnostic_library integration
         self.time_agnostic_library_config = os.path.join(os.path.dirname(config), 'time_agnostic_library_config.json')
         if not os.path.exists(self.time_agnostic_library_config):
             generate_config_file(config_path=self.time_agnostic_library_config, dataset_urls=[self.triplestore_url], dataset_dirs=list(),
                 provenance_urls=settings['provenance_endpoints'], provenance_dirs=list(), 
-                blazegraph_full_text_search=settings['blazegraph_full_text_search'], graphdb_connector_name=settings['graphdb_connector_name'], 
+                blazegraph_full_text_search=settings['blazegraph_full_text_search'], fuseki_full_text_search=settings['fuseki_full_text_search'], 
+                virtuoso_full_text_search=settings['virtuoso_full_text_search'], graphdb_connector_name=settings['graphdb_connector_name'], 
                 cache_endpoint=settings['cache_endpoint'], cache_update_endpoint=settings['cache_update_endpoint'])
 
-    def prepare_folders(self) -> Set[str]:
+    def prepare_folders(self) -> List[str]:
         completed = init_cache(self.cache_path)
         files_in_input_csv_dir = {filename for filename in os.listdir(self.input_csv_dir) if filename.endswith('.csv')}
-        files_to_be_processed = sort_files(files_in_input_csv_dir.difference(completed))
+        files_to_be_processed = sort_files(list(files_in_input_csv_dir.difference(completed)))
         for dir in [self.output_csv_dir, self.indexes_dir, self.output_rdf_dir]:
             pathoo(dir)
         if self.rdf_output_in_chunks:
@@ -97,7 +96,7 @@ class MetaProcess:
             return {'message': 'skip'}, cache_path, errors_path, filename
         try:
             filepath = os.path.join(self.input_csv_dir, filename)
-            data = get_data(filepath)
+            data = get_csv_data(filepath)
             supplier_prefix = f'{self.supplier_prefix}0' if worker_number is None else f'{self.supplier_prefix}{str(worker_number)}0'
             # Curator
             self.info_dir = os.path.join(self.info_dir, supplier_prefix) if worker_number else self.info_dir
@@ -122,10 +121,12 @@ class MetaProcess:
             prov = ProvSet(creator, self.base_iri, creator_info_dir, wanted_label=False)
             prov.generate_provenance()
             # Storer
-            res_storer = Storer(creator, context_map={}, dir_split=self.dir_split_number, n_file_item=self.items_per_file, default_dir=self.default_dir, output_format='json-ld')
-            prov_storer = Storer(prov, context_map={}, dir_split=self.dir_split_number, n_file_item=self.items_per_file, output_format='json-ld')
-            with suppress_stdout():
-                self.store_data_and_prov(res_storer, prov_storer, filename)
+            repok  = Reporter(print_sentences = False)
+            reperr = Reporter(print_sentences = True, prefix='[Storer: ERROR] ')
+            res_storer = Storer(abstract_set=creator, repok=repok, reperr=reperr, context_map={}, dir_split=self.dir_split_number, n_file_item=self.items_per_file, default_dir=self.default_dir, output_format='json-ld', zip_output=self.zip_output_rdf)
+            prov_storer = Storer(abstract_set=prov, repok=repok, reperr=reperr, context_map={}, dir_split=self.dir_split_number, n_file_item=self.items_per_file, output_format='json-ld', zip_output=self.zip_output_rdf)
+            # with suppress_stdout():
+            self.store_data_and_prov(res_storer, prov_storer, filename)
             return {'message': 'success'}, cache_path, errors_path, filename
         except Exception as e:
             template = "An exception of type {0} occurred. Arguments:\n{1!r}"
@@ -145,20 +146,29 @@ class MetaProcess:
             prov_storer.store_all(self.output_rdf_dir, self.base_iri, self.context_path)
             res_storer.upload_all(triplestore_url=self.triplestore_url, base_dir=self.output_rdf_dir, batch_size=100)
 
+    def save_data(self):
+        output_dirname = f"meta_output_{datetime.now().strftime('%Y-%m-%dT%H_%M_%S_%f')}.zip"
+        dirs_to_zip = [self.base_output_dir, self.output_rdf_dir] if self.distinct_output_dirs else [self.base_output_dir]
+        zipit(dirs_to_zip, output_dirname)
+
 def run_meta_process(meta_process:MetaProcess, resp_agents_only:bool=False) -> None:
     delete_lock_files(base_dir=meta_process.base_output_dir)
     files_to_be_processed = meta_process.prepare_folders()
+    is_unix = platform in {'linux', 'linux2', 'darwin'}
     max_workers = meta_process.workers_number
     if max_workers == 0:
         workers = list(range(1, os.cpu_count()))
     elif max_workers == 1:
         workers = [None]
     else:
-        multiples_of_ten = {i for i in range(1, max_workers+1) if int(i) % 10 == 0}
+        tens = int(str(max_workers)[:-1]) if max_workers >= 10 else 0
+        multiples_of_ten = {i for i in range(1, max_workers + tens + 1) if int(i) % 10 == 0}
         workers = [i for i in range(1, max_workers+len(multiples_of_ten)+1) if i not in multiples_of_ten]
-    is_unix = platform in {'linux', 'linux2', 'darwin'}
+        if is_unix:
+            os.sched_setaffinity(0, set(range(0, max_workers)))
     generate_gentle_buttons(meta_process.base_output_dir, meta_process.config, is_unix)
-    files_chunks = chunks(list(files_to_be_processed), 1000) if is_unix else [files_to_be_processed]
+    zip_every_n_files = round(max_workers * 300, -3) if max_workers > 3 else 500
+    files_chunks = chunks(list(files_to_be_processed), zip_every_n_files) if is_unix else [files_to_be_processed]
     for files_chunk in files_chunks:
         with ProcessPool(max_workers=max_workers, max_tasks=1) as executor:
             for file_to_be_processed, worker_number in zip(files_chunk, cycle(workers)):
@@ -166,12 +176,11 @@ def run_meta_process(meta_process:MetaProcess, resp_agents_only:bool=False) -> N
                     function=meta_process.curate_and_create, 
                     args=(file_to_be_processed, meta_process.cache_path, meta_process.errors_path, worker_number, resp_agents_only)) 
                 future.add_done_callback(task_done) 
-        delete_lock_files(base_dir=meta_process.base_output_dir)
         if is_unix and not os.path.exists(os.path.join(meta_process.base_output_dir, '.stop')):
-            save_results(meta_process.base_output_dir)
-    if os.path.exists(meta_process.cache_path) and not os.path.exists(os.path.join(meta_process.base_output_dir, '.stop')):
-        os.rename(meta_process.cache_path, meta_process.cache_path.replace('.txt', f'_{datetime.now().strftime("%Y-%m-%dT%H_%M_%S_%f")}.txt'))
-    if not is_unix:
+            meta_process.save_data()
+    if not os.path.exists(os.path.join(meta_process.base_output_dir, '.stop')):
+        if os.path.exists(meta_process.cache_path):
+            os.rename(meta_process.cache_path, meta_process.cache_path.replace('.txt', f'_{datetime.now().strftime("%Y-%m-%dT%H_%M_%S_%f")}.txt'))
         delete_lock_files(base_dir=meta_process.base_output_dir)
 
 def task_done(task_output:ProcessFuture) -> None:
@@ -204,23 +213,17 @@ def delete_lock_files(base_dir:list) -> None:
             if filename.endswith('.lock'):
                 os.remove(os.path.join(dirpath, filename))
 
-def save_results(output_dirpath:str) -> None:
-    output_dirname = f"meta_output_{datetime.now().strftime('%Y-%m-%dT%H_%M_%S_%f')}"
-    parent_dir = Path(output_dirpath)
-    parent_dir = parent_dir.parent.absolute()
-    make_archive(base_name=output_dirname, format='zip', base_dir=output_dirpath)
-
 def generate_gentle_buttons(dir:str, config:str, is_unix:bool):
     if os.path.exists(os.path.join(dir, '.stop')):
         os.remove(os.path.join(dir, '.stop'))
     ext = 'sh' if is_unix else 'bat'
     with open (f'gently_run.{ext}', 'w') as rsh:
-        rsh.write(f'python -m oc_meta.lib.stopper -t "{dir}" --remove\npython -m oc_meta.run.meta_process -c {config}')
+        rsh.write(f'{executable} -m oc_meta.lib.stopper -t "{dir}" --remove\n{executable} -m oc_meta.run.meta_process -c {config}')
     with open (f'gently_stop.{ext}', 'w') as rsh:
-        rsh.write(f'python -m oc_meta.lib.stopper -t "{dir}" --add')
+        rsh.write(f'{executable} -m oc_meta.lib.stopper -t "{dir}" --add')
 
 
-if __name__ == '__main__':
+if __name__ == '__main__': # pragma: no cover
     arg_parser = ArgumentParser('meta_process.py', description='This script runs the OCMeta data processing workflow')
     arg_parser.add_argument('-c', '--config', dest='config', required=True, help='Configuration file directory')
     args = arg_parser.parse_args()
